# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 内部错误。
INTERNALERROR = 'InternalError'

# 请求超时,请重试。
INTERNALERROR_ERRTIMEOUT = 'InternalError.ErrTimeOut'

# 账号未开通服务。
INVALIDPARAMETERVALUE_ACCOUNTNOTFOUND = 'InvalidParameterValue.AccountNotFound'

# 无效的公网ip地址。
INVALIDPARAMETERVALUE_INVALIDIP = 'InvalidParameterValue.InvalidIp'

# 手机号码无效。
INVALIDPARAMETERVALUE_INVALIDMOBILENUMBER = 'InvalidParameterValue.InvalidMobileNumber'
